from setuptools import setup, find_packages
setup(name="edphelper",
      version="0.11.1",
      py_modules=["helper"],
      install_requires=['typing==3.7.4.1;python_version<="2.7"',
                        'enum34==1.1.6;python_version<="2.7"',
                        'tzlocal==2.0.0',
                        'unidecode==1.1.1'],
      url="http://www.e-deploy.com.br",
      author="Eduardo Almeida",
      author_email="eduardo.almeida@e-deploy.com.br"
)
